@@ -17,16 +17,17 @@ class DictTransformer(Transformer):
     def int_lit(self, args: List) -> int:
         return int("".join([str(arg) for arg in args]))
 
-    def true_lit(self, args: List) -> bool:
-        return True
-
-    def false_lit(self, args: List) -> bool:
-        return False
-
-    def null_lit(self, args: List) -> None:
-        return None
-
     def expr_term(self, args: List) -> Any:
+        args = self.strip_new_line_tokens(args)
+
+        #
+        if args[0] == "true":
+            return True
+        if args[0] == "false":
+            return False
+        if args[0] == "null":
+            return None
+
         # if the expression starts with a paren then unwrap it
         if args[0] == "(":
             return args[1]
@@ -34,7 +35,12 @@ class DictTransformer(Transformer):
         return args[0]
 
     def index_expr_term(self, args: List) -> str:
-        return "%s[%s]" % (str(args[0]), str(args[1]))
+        args = self.strip_new_line_tokens(args)
+        return "%s%s" % (str(args[0]), str(args[1]))
+
+    def index(self, args: List) -> str:
+        args = self.strip_new_line_tokens(args)
+        return "[%s]" % (str(args[0]))
 
     def get_attr_expr_term(self, args: List) -> str:
         return "%s.%s" % (str(args[0]), str(args[1]))
@@ -117,6 +123,7 @@ class DictTransformer(Transformer):
         return "".join([str(arg) for arg in args])
 
     def binary_term(self, args: List) -> str:
+        args = self.strip_new_line_tokens(args)
         return " ".join([str(arg) for arg in args])
 
     def body(self, args: List) -> Dict[str, List]:
